@@ -8,11 +8,13 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
@@ -20,9 +22,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticsearch",
-    "1.88.0",
+    "1.90.0",
     __name__[0:-6],
-    "aws-elasticsearch@1.88.0.jsii.tgz",
+    "aws-elasticsearch@1.90.0.jsii.tgz",
 )
 
 __all__ = [
